//
// JTypist v3.1 - Java typing tutor program for UNIX systems
// Copyright (C) 2000  Simon Baldwin (simonb@sco.com)
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
//
// History class - maintain a list of recently visited lessons
//
import java.util.Vector;
import java.util.Enumeration;

/**
 * Maintain a list of recently visited lessons
 */
public class History {

	/**
	 * Default size of a history list.
	 */
	public static final int	DEFAULT_SIZE	= 20;

	// size, and vector of lessons in the history list
	private Vector		history;//	= null;
	private int		size;//		= 0;

	/**
	 * Create a new history, with a given size.
	 */
	public History( int size ) {
		this.size	= size;
		history		= new Vector( size );
	}

	/**
	 * Create a new history, with a default size.
	 */
	public History() {
		this( DEFAULT_SIZE );
	}

	/**
	 * Check if a lesson is already in this history.
	 */
	public boolean remembers( Lesson lesson ) {
		return ( history.contains( lesson ));
	}

	/**
	 * Add a lesson to the history list, if not there already.
	 * This will remove the oldest from the list, if the list
	 * is already at maximum capacity.
	 */
	public void remember( Lesson lesson ) {

		// scan the list to ensure we don't already have this lesson
		if ( ! history.contains( lesson )) {

			// drop the oldest item if the list is full
			if ( history.size() >= size )
				history.removeElementAt( 0 );

			// add the new lesson in
			history.addElement( lesson );
		}
	}


	/**
	 * Get the items in the history list.
	 */
	public Enumeration relate() {
		return ( history.elements() );
	}

	/**
	 * Flush the entire history away.
	 */
	public void forget() {
		history.setSize( 0 );
	}


	/**
	 * Printout method.
	 */
	public String toString() {
		String ret_str = getClass().getName() + "{";
		for ( int index = 0; index < history.size(); index++ ) {
			ret_str += "lesson[" + index + "]="
					+ history.elementAt( index );
		}
		return ( ret_str + "}" );
	}


	/**
	 * Class test code.
	 */
	public static void main( String args[] ) {
		System.out.println( "*** CLASS TEST CODE ***" );

		Lesson l1	= new TutorialLesson( "Test 1", "Test text 1" );
		Lesson l2	= new TutorialLesson( "Test 2", "Test text 2" );
		Lesson l3	= new TutorialLesson( "Test 3", "Test text 3" );
		Lesson l4	= new TutorialLesson( "Test 4", "Test text 4" );
		History history	= new History( 3 );
		System.out.println( "Empty history: " + history );
		history.remember( l1 ); history.remember( l1 );
		System.out.println( "L1 history: " + history );
		history.remember( l2 ); history.remember( l2 );
		history.remember( l3 ); history.remember( l3 );
		System.out.println( "Full history: " + history );
		history.remember( l4 );
		System.out.println( "Rolled history: " + history );
	}
}
